@@ -5,7 +5,7 @@ mod route;
 
 pub use msg::{
     create_batch_update_orders_msg, create_derivative_market_order_msg, create_subaccount_transfer_msg, DerivativeOrder, InjectiveMsg,
-    InjectiveMsgWrapper, OrderData, SpotOrder,
+    InjectiveMsgWrapper, OrderData, OrderInfo, SpotOrder,
 };
 
 pub use querier::InjectiveQuerier;
